
#################################################################################################
#
# Node Generator
#
# Writen by:  Erol Kalkan
# Last modified:  Jan. 2004
#
# Objective: 7-Story Van-Nuys RC 
#
# Units: kip-in      
#################################################################################################  
set masscor 1.2;
set IFM [expr 0.097*$masscor];   #nodal gravity load for interior first storey column
set EFM [expr 0.0485*$masscor];   #nodal gravity load for exterior first storey column

set IM [expr 0.088*$masscor];    #nodal mass for interior column
set EM [expr 0.044*$masscor];    #nodal gravity load for exterior column

set IRM [expr 0.077*$masscor];   #nodal gravity load for interior roof column
set ERM [expr 0.0385*$masscor];  #nodal gravity load for exterior roof column

set xa -900; #nodal x coordinates
set xb -675;
set xc -450;
set xd -225; 
set xe    0;
set xf  225;
set xg  450;
set xh  675;
set xj  900;

set h1  162; 	# nodal z coordinates
set h2  266.5;
set h3  371;
set h4  475.5;
set h5  580;
set h6  684.5;
set h7  788.5;

#####################################################################
# DEFINE NODAL COORDINATES IN INCHES AND NODAL MASSES IN KIP-SEC^2/IN
#    tag   X    Y           Mx    My   Mrot
# Base
node  1 $xa    0  -mass     0     0     0
node  2 $xb    0  -mass     0     0     0
node  3 $xc    0  -mass     0     0     0
node  4 $xd    0  -mass     0     0     0
node  5 $xe    0  -mass     0     0     0
node  6 $xf    0  -mass     0     0     0
node  7 $xg    0  -mass     0     0     0
node  8 $xh    0  -mass     0     0     0
node  9 $xj    0  -mass     0     0     0

# Story 1
node 10 $xa  $h1   -mass  $EFM    0     0
node 11 $xb  $h1   -mass  $IFM    0     0     
node 12 $xc  $h1   -mass  $IFM    0     0     
node 13 $xd  $h1   -mass  $IFM    0     0     
node 14 $xe  $h1   -mass  $IFM    0     0     
node 15 $xf  $h1   -mass  $IFM    0     0     
node 16 $xg  $h1   -mass  $IFM    0     0     
node 17 $xh  $h1   -mass  $IFM    0     0     
node 18 $xj  $h1   -mass  $EFM    0     0     

# Story 2
node 19 $xa  $h2   -mass  $EM    0     0
node 20 $xb  $h2   -mass  $IM    0     0     
node 21 $xc  $h2   -mass  $IM    0     0     
node 22 $xd  $h2   -mass  $IM    0     0     
node 23 $xe  $h2   -mass  $IM    0     0     
node 24 $xf  $h2   -mass  $IM    0     0     
node 25 $xg  $h2   -mass  $IM    0     0     
node 26 $xh  $h2   -mass  $IM    0     0     
node 27 $xj  $h2   -mass  $EM    0     0     

# Story 3
node 28 $xa  $h3   -mass  $EM    0     0
node 29 $xb  $h3   -mass  $IM    0     0     
node 30 $xc  $h3   -mass  $IM    0     0     
node 31 $xd  $h3   -mass  $IM    0     0     
node 32 $xe  $h3   -mass  $IM    0     0     
node 33 $xf  $h3   -mass  $IM    0     0     
node 34 $xg  $h3   -mass  $IM    0     0     
node 35 $xh  $h3   -mass  $IM    0     0     
node 36 $xj  $h3   -mass  $EM    0     0     

# Story 4
node 37 $xa  $h4   -mass  $EM    0     0
node 38 $xb  $h4   -mass  $IM    0     0     
node 39 $xc  $h4   -mass  $IM    0     0     
node 40 $xd  $h4   -mass  $IM    0     0     
node 41 $xe  $h4   -mass  $IM    0     0     
node 42 $xf  $h4   -mass  $IM    0     0     
node 43 $xg  $h4   -mass  $IM    0     0     
node 44 $xh  $h4   -mass  $IM    0     0     
node 45 $xj  $h4   -mass  $EM    0     0     

# Story 5
node 46 $xa  $h5   -mass  $EM    0     0
node 47 $xb  $h5   -mass  $IM    0     0     
node 48 $xc  $h5   -mass  $IM    0     0     
node 49 $xd  $h5   -mass  $IM    0     0     
node 50 $xe  $h5   -mass  $IM    0     0     
node 51 $xf  $h5   -mass  $IM    0     0     
node 52 $xg  $h5   -mass  $IM    0     0     
node 53 $xh  $h5   -mass  $IM    0     0     
node 54 $xj  $h5   -mass  $EM    0     0     

# Story 6
node 55 $xa  $h6   -mass  $EM    0     0
node 56 $xb  $h6   -mass  $IM    0     0     
node 57 $xc  $h6   -mass  $IM    0     0     
node 58 $xd  $h6   -mass  $IM    0     0     
node 59 $xe  $h6   -mass  $IM    0     0     
node 60 $xf  $h6   -mass  $IM    0     0     
node 61 $xg  $h6   -mass  $IM    0     0     
node 62 $xh  $h6   -mass  $IM    0     0     
node 63 $xj  $h6   -mass  $EM    0     0     

# Story 7
node 64 $xa  $h7   -mass  $ERM    0     0
node 65 $xb  $h7   -mass  $IRM    0     0     
node 66 $xc  $h7   -mass  $IRM    0     0     
node 67 $xd  $h7   -mass  $IRM    0     0     
node 68 $xe  $h7   -mass  $IRM    0     0     
node 69 $xf  $h7   -mass  $IRM    0     0     
node 70 $xg  $h7   -mass  $IRM    0     0     
node 71 $xh  $h7   -mass  $IRM    0     0     
node 72 $xj  $h7   -mass  $ERM    0     0     

#####################################################################
# SINGLE POINT CONSTRAINTS
#   node DX DY RZ
fix   1   1  1  1
fix   2   1  1  1
fix   3   1  1  1
fix   4   1  1  1
fix   5   1  1  1
fix   6   1  1  1
fix   7   1  1  1
fix   8   1  1  1
fix   9   1  1  1
#####################################################################
puts "Finished creating nodes and restraints ..."






